@@ -3,7 +3,8 @@
 //! For reading SGFs your starting point will likely be [`go::parse`]. For parsing non-go games
 //! check out the [`parse`](`parse()`) function.
 //!
-//! For writing SGFs check out [`serialize`](`serialize()`).
+//! For writing SGFs check out [`SgfNode::serialize`] for writing single game trees or
+//! [`serialize`](`serialize()`) for writing whole collections.
 
 #[macro_use]
 mod prop_macro;
@@ -11,14 +12,14 @@ mod prop_macro;
 pub mod go;
 pub mod unknown_game;
 
-mod games;
+mod game_tree;
 mod lexer;
 mod parser;
 mod props;
 mod serialize;
 mod sgf_node;
 
-pub use games::{GameTree, GameType};
+pub use game_tree::{GameTree, GameType};
 pub use lexer::LexerError;
 pub use parser::{parse, SgfParseError};
 pub use props::{Color, Double, PropertyType, SgfProp, SimpleText, Text};
